/*
 * libfx - a library for FXS and FXO signaling
 *
 * fx.h
 *
 * Written by Steve Underwood <steveu@coppice.org>
 *
 * Copyright (C) 2003 Steve Underwood
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: fx.h,v 1.19 2005/12/20 15:57:08 steveu Exp $
 */

#if !defined(_FX_H_)
#define _FX_H_

enum
{
    FX_PROT_LS = 1,
    FX_PROT_GS,
    FX_PROT_KS
};

/* This structure should contain everything to control an FXS or FXO. */
struct fx_signaling_state_s
{
    int dropped;

    /*! \brief The nature of the call - free, charged, SIT, etc. */
    int call_type;
    /*! \brief Timer used to ensure the line is reliably usable, after releasing
        from the blocked state. */
    int local_unblocking_timer;
    /*! \brief Seize wait timer, using to impose a small delay between seizing
        the line, and sending anything (usually dialing). */
    int seize_wait_timer;
    /*! \brief Timeout while waiting for the line to be answered. */
    int wait_for_answer_timer;
    /*! \brief TRUE if local end is blocked. */
    int local_blocked;

    /*! \brief Country dependant category code. */
    int calling_party_category;

    dtmf_rx_state_t dtmf_rx_state;
    dtmf_tx_state_t dtmf_tx_state;
    adsi_rx_state_t adsi_rx_state;
    adsi_tx_state_t adsi_tx_state;
    super_tone_rx_state_t *super_tone_rx_state;
    super_tone_tx_state_t super_tone_tx_state;

    /*! \brief The delay to be used between seizing the line and sending anything
        (usually dialing). */
    int seize_wait;
    /*! \brief the maximum time we will wait, in seconds, for calls to be answered. 60s is
               common practice. */
    int max_wait_for_answer;
    /*! \brief TRUE is we permit outgoing as well as incoming calls. */
    int outgoing_calls_allowed;

    /*! \brief Supervisory tone set descriptor. */
    super_tone_set_t *super_tones;

    int distinctive_ring;
    int cid_rings;
    /*! \brief TRUE to use pulse dialing. */
    int pulse_dial;

    int alarms;

    /*! \brief The current call context. */
    uc_call_t *call;
};

#endif
/*- End of file ------------------------------------------------------------*/
